# AutoVar

[![PyPI version](https://badge.fury.io/py/autovar.svg)](https://badge.fury.io/py/autovar)
[![Build Status](https://travis-ci.org/yangarbiter/autovar.svg?branch=master)](https://travis-ci.org/yangarbiter/autovar)
[![codecov](https://codecov.io/gh/yangarbiter/autovar/branch/master/graph/badge.svg)](https://codecov.io/gh/yangarbiter/autovar)


```
pip install --upgrade git+https://github.com/yangarbiter/autovar.git
```


A [template](https://github.com/yangarbiter/autovar_project_template) to start a project using autovar
